summaryrefslogtreecommitdiffstats
path: root/lib/interfaces/codemodel.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/interfaces/codemodel.h')
-rw-r--r--lib/interfaces/codemodel.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/lib/interfaces/codemodel.h b/lib/interfaces/codemodel.h
index f85ff4c3..343c6169 100644
--- a/lib/interfaces/codemodel.h
+++ b/lib/interfaces/codemodel.h
@@ -706,10 +706,10 @@ public:
virtual bool isClass() const { return true; }
/**@return The scope of the class. Scope is a string list composed from names of tqparent classes and namespaces.*/
TQStringList scope() const { return m_scope; }
/**Sets the scope of this class.
- @param scope The scope - a list of tqparent classes and namespaces.*/
+ @param scope The scope - a list of parent classes and namespaces.*/
void setScope( const TQStringList& scope ) { m_scope = scope; }
/**@return The list of base class names.*/
@@ -1256,7 +1256,7 @@ public:
virtual bool isFunction() const { return true; }
/**@return The scope of the function. Scope is a string list composed
- from names of tqparent functions, classes and namespaces.*/
+ from names of parent functions, classes and namespaces.*/
TQStringList scope() const { return m_scope; }
/**Sets the scope of the function.
@@ -706,10 +706,10 @@ public:
virtual bool isClass() const { return true; }
- /**@return The scope of the class. Scope is a string list composed from names of tqparent classes and namespaces.*/
+ /**@return The scope of the class. Scope is a string list composed from names of parent classes and namespaces.*/
TQStringList scope() const { return m_scope; }
/**Sets the scope of this class.